import { Spinner } from '@wordpress/components'
import { __, sprintf } from '@wordpress/i18n'
import { TourItem } from '@assist/components/task-items/TourItem'
import { useTours } from '@assist/hooks/useTours'
import { useTourStore, useTourStoreReady } from '@assist/state/Tours'

export const ToursList = () => {
    const { tours, loading, error } = useTours()
    const { wasOpened } = useTourStore()
    const readyTours = useTourStoreReady()

    // Now filter all tasks that are marked as completed
    const completed = tours?.filter((tour) => wasOpened(tour.slug))

    if (loading || !readyTours || error) {
        return (
            <div className="my-4 w-full flex justify-center mx-auto border border-gray-400 p-2 lg:p-8">
                <Spinner />
            </div>
        )
    }

    if (tours?.length === 0) {
        return (
            <div
                className="my-4 w-full mx-auto border border-gray-400 p-2 lg:p-8"
                data-test="no-tours-found">
                {__('No tours found...', 'extendify')}
            </div>
        )
    }

    return (
        <div className="my-4 w-full mx-auto bg-white border border-gray-400 p-4">
            <div className="mb-6 flex gap-0 flex-col">
                <h2 className="my-0 text-lg">
                    {__('Get going with these WordPress tours', 'extendify')}
                </h2>
                <div className="flex gap-1">
                    <span>
                        {sprintf(
                            // translators: %s is the number of tasks
                            __('%s completed', 'extendify'),
                            completed.length,
                        )}
                    </span>
                </div>
            </div>
            <div
                className="all-tours w-full border border-b-0 border-gray-400"
                data-test="all-tours">
                {tours.map((tour) => (
                    <TourItemWrapper key={tour.slug} tour={tour} />
                ))}
            </div>
        </div>
    )
}

const TourItemWrapper = ({ tour }) => (
    <div className="p-3 flex gap-3 justify-between border-0 border-b border-gray-400 bg-white relative items-center">
        <TourItem tour={tour} />
    </div>
)
