import { Spinner } from '@wordpress/components'
import { __ } from '@wordpress/i18n'
import { Icon, chevronRightSmall } from '@wordpress/icons'
import { useRouter } from '@assist/hooks/useRouter'
import { useSupportArticles } from '@assist/hooks/useSupportArticles'
import { useHelpCenterStore } from '@assist/state/HelpCenter'

export const SupportArticles = () => {
    const { data: articles, loading, error } = useSupportArticles()
    const { navigateTo } = useRouter()
    const { pushArticle, clearArticles } = useHelpCenterStore()
    const userLanguage = window.extAssistData.wpLanguage

    if (loading || error) {
        return (
            <div className="w-full flex justify-center mx-auto bg-gray-50 border border-gray-400 p-2 lg:p-4">
                <Spinner />
                {error && <p className="text-sm text-red-500">{error}</p>}
            </div>
        )
    }

    if (articles && articles?.length === 0) {
        return (
            <div className="w-full mx-auto bg-white border border-gray-400 p-2 lg:p-4">
                {__('No support articles found...', 'extendify')}
            </div>
        )
    }

    return (
        <div className="w-full bg-white border border-gray-400 mx-auto text-base">
            <h2 className="text-base leading-tight m-0 border-b border-gray-400 bg-gray-50 px-4 py-3.5">
                {userLanguage.startsWith('en')
                    ? __('Help Center', 'extendify')
                    : __('Help Center (English only)', 'extendify')}
            </h2>
            <div className="w-full mx-auto text-sm px-4 py-6">
                {articles.slice(0, 5).map(({ slug, extendifyTitle }) => (
                    <button
                        type="button"
                        key={slug}
                        onClick={(e) => {
                            e.preventDefault()
                            clearArticles()
                            pushArticle({ slug, title: extendifyTitle })
                            navigateTo('help-center')
                        }}
                        className="flex items-center justify-between no-underline hover:underline text-black hover:text-partner-primary-bg bg-transparent mb-2 w-full cursor-pointer">
                        <span>{extendifyTitle}</span>
                        <Icon
                            icon={chevronRightSmall}
                            className="fill-current"
                        />
                    </button>
                ))}
            </div>
            <div className="px-4 py-2 border-t border-gray-400">
                <a
                    href="admin.php?page=extendify-assist#help-center"
                    className="inline-flex items-center no-underline text-sm text-design-main">
                    {__('Show all', 'extendify')}
                    <Icon icon={chevronRightSmall} className="fill-current" />
                </a>
            </div>
        </div>
    )
}
